@@ -31,7 +31,7 @@ import uuid
 
 from datetime import datetime
 from pprint import pp
-# from periodic import Periodic
+from periodic import Periodic
 
 
 class UMF_Message:
@@ -522,15 +522,13 @@ class HydraPy:
         self._redis = await aioredis.create_redis_pool(redis_url, encoding='utf-8')
 
         await self._register_service()
-        # p = Periodic(self._PRESENCE_UPDATE_INTERVAL, self._hydra_events)
-        # await p.start()
+        p = Periodic(self._PRESENCE_UPDATE_INTERVAL, self._hydra_events)
+        await p.start()
 
         # TODO: determine best way to close
         # self._redis.close()
         # await self._redis.wait_closed()
-
         return self.get_service_info()
 
     async def run(self):
-        await self._hydra_events()
         await self._redis.wait_closed()
